from django.core.management import BaseCommand, CommandError
import mysql.connector

from ippidb.models import Bibliography, Protein, Taxonomy, MolecularFunction, Domain

class Command(BaseCommand):

    help = "Import data from the local v1 database"

    def add_arguments(self, parser):
        parser.add_argument(
            '--bibliographies',
            action='store_true',
            dest='bibliographies',
            default=False,
            help='Flush and migrate bibliographies',
        )
        parser.add_argument(
            '--proteins',
            action='store_true',
            dest='proteins',
            default=False,
            help='Flush and migrate proteins',
        )
        parser.add_argument(
            '--domains',
            action='store_true',
            dest='domains',
            default=False,
            help='Flush and migrate domains',
        )
        parser.add_argument(
            '--stoponfail',
            action='store_true',
            dest='stoponfail',
            default=False,
            help='Stop on fail',
        )


    def handle(self, *args, **options):
        conn = mysql.connector.connect(host="localhost",user="root",password="ippidb", database="ippidb")
        cursor = conn.cursor()
        if options['bibliographies']:
            cursor.execute("""SELECT * FROM biblio""")
            rows = cursor.fetchall()
            Bibliography.objects.all().delete()
            self.stdout.write(self.style.SUCCESS('Successfully flushed bibliography table'))
            for row in rows:
                try:
                    b = Bibliography()
                    if row[1]=='article':
                        b.source = 'PM'
                    else:
                        b.source = 'PT'
                    b.id_source = row[2]
                    b.save()
                except Exception as e:
                    self.stdout.write(self.style.ERROR('Failed inserting {}'.format(row[2])))
                else:
                    self.stdout.write(self.style.SUCCESS('Successfully inserted {}'.format(row[2])))
        if options['proteins']:
            cursor.execute("""SELECT * FROM protein""")
            rows = cursor.fetchall()
            Protein.objects.all().delete()
            self.stdout.write(self.style.SUCCESS('Successfully flushed protein table'))
            Taxonomy.objects.all().delete()
            self.stdout.write(self.style.SUCCESS('Successfully flushed taxonomy table'))
            MolecularFunction.objects.all().delete()
            self.stdout.write(self.style.SUCCESS('Successfully flushed molecular function table'))
            for row in rows:
                try:
                    p = Protein()
                    p.uniprot_id = row[1]
                    p.save()
                except Exception as e:
                    if options['stoponfail']:
                        import traceback
                        self.stderr.write(traceback.format_exc())
                        raise CommandError('Failed inserting {} {}'.format(row[1], row[2]))
                    else:
                        self.stdout.write(self.style.ERROR('Failed inserting {} {}'.format(row[1], row[2])))
                else:
                    self.stdout.write(self.style.SUCCESS('Successfully inserted {} {}'.format(row[1], row[2])))
        if options['domains']:
            cursor.execute("""SELECT * FROM domain""")
            rows = cursor.fetchall()
            Domain.objects.all().delete()
            self.stdout.write(self.style.SUCCESS('Successfully flushed domain table'))
            for row in rows:
                try:
                    p = Domain()
                    p.pfam_acc = row[2]
                    p.domain_family = row[4]
                    p.save()
                except Exception as e:
                    if options['stoponfail']:
                        import traceback
                        self.stderr.write(traceback.format_exc())
                        raise CommandError('Failed inserting {} {}'.format(row[1], row[2]))
                    else:
                        self.stdout.write(self.style.ERROR('Failed inserting {} {}'.format(row[1], row[2])))
                else:
                    self.stdout.write(self.style.SUCCESS('Successfully inserted {} {}'.format(row[1], row[2])))
            
